pub struct Base {
pub temperature: Option<f64>,
pub top_p: Option<f64>,
pub stream: bool,
pub n: Option<usize>,
pub user: String,
pub max_tokens: Option<usize>,
}Expand description
OpenAI Chat Completion API
Fields
temperature: Option<f64>What sampling temperature to use.
top_p: Option<f64>An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass.
stream: boolIf set, the server will stream back partial progress.
n: Option<usize>How many completions to generate for each prompt.
user: StringUser ID to associate with the request.
max_tokens: Option<usize>The maximum number of tokens to generate.